is_svyrep: Check if object is a replicate survey object (created by...

View source: R/helpers.R

is_svyrepR Documentation

Check if object is a replicate survey object (created by svrepdesign())

Description

Check if object is a replicate survey object (created by svrepdesign())

Usage

is_svyrep(x)

Arguments

x

object to be tested

Value

logical

Author(s)

Tom Elliott


iNZightTools documentation built on July 27, 2026, 5:08 p.m.